![coverage](https://github.com/almazkun/npss/blob/main/.github/coverage.svg)

# npss
Your New Password!

# Why?
When need some password (token or random url safe string of specified length) quickly.

# Perks:
Generate random string with specified length or length of 30 by default.
* No dependencies.
* Random.
* Url safe.
* At least one `-` included.

# Installation:
```bash
pip install npss
```

# Usage:
```bash 
npss
```
    >>>
    J_9oE0uToBaw6qDzUAUI-hZ3PJC93B

```bash 
npss 255
```
    >>>
    JwAiFQjuFizl6g1Thzx1AQdn39ozrPqsRJ4thyrs9OCjU28nUAx9k3fmB0jcSTtkZBVhF-DDV9-0zeod0OPN13k0gOEsA4FtSBtr6ckq81lQewOuLBUbFNUlKLH63Z6GSdZtuTidcQrvlVErnaY-pFb4xX8Jmj2jzJDpp6HvctEu5ycQq3VevlBwx9dIf8VUuO9jwZPsQnc022jbwBv00shByBOKCoO5I3TLGwnQEWaRHsWfyXeb6fTyzLtGH2-

# Uninstall:
```bash
pip uninstall npss
```
